@@ -21,9 +21,15 @@ struct Config {
 }
 
 fn main() -> Result<(), PropertyError> {
-    let _ = Salak::builder()
+    env_logger::init();
+    let env = Salak::builder()
         .configure_description::<Config>()
         .configure_args(app_info!())
+        .register_default_resource::<()>()?
         .build()?;
+    for _i in 0..1000 {
+        log::info!("Round {}", _i);
+        let _ = env.get_resource::<()>()?;
+    }
     Ok(())
 }
